@@ -1,7 +1,7 @@
 /*
  * gui-nicklist.c - nicklist functions (used by all GUI)
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -34,14 +34,14 @@
 #include <ctype.h>
 
 #include "../core/weechat.h"
-#include "../core/wee-config.h"
-#include "../core/wee-hashtable.h"
-#include "../core/wee-hdata.h"
-#include "../core/wee-hook.h"
-#include "../core/wee-infolist.h"
-#include "../core/wee-log.h"
-#include "../core/wee-string.h"
-#include "../core/wee-utf8.h"
+#include "../core/core-config.h"
+#include "../core/core-hashtable.h"
+#include "../core/core-hdata.h"
+#include "../core/core-hook.h"
+#include "../core/core-infolist.h"
+#include "../core/core-log.h"
+#include "../core/core-string.h"
+#include "../core/core-utf8.h"
 #include "../plugins/plugin.h"
 #include "gui-nicklist.h"
 #include "gui-buffer.h"
@@ -60,18 +60,14 @@ gui_nicklist_send_signal (const char *signal, struct t_gui_buffer *buffer,
                           const char *arguments)
 {
     char *str_args;
-    int length;
 
     if (buffer)
     {
-        length = 128 + ((arguments) ? strlen (arguments) : 0) + 1 + 1;
-        str_args = malloc (length);
-        if (str_args)
+        if (string_asprintf (&str_args,
+                             "0x%lx,%s",
+                             (unsigned long)buffer,
+                             (arguments) ? arguments : "") >= 0)
         {
-            snprintf (str_args, length,
-                      "0x%lx,%s",
-                      (unsigned long)(buffer),
-                      (arguments) ? arguments : "");
             (void) hook_signal_send (signal,
                                      WEECHAT_HOOK_SIGNAL_STRING, str_args);
             free (str_args);
@@ -182,22 +178,18 @@ gui_nicklist_insert_group_sorted (struct t_gui_nick_group **groups,
 }
 
 /*
- * Searches for a group in nicklist (this function must not be called directly).
+ * Searches for a group in nicklist by id (this function must not be called
+ * directly).
  *
  * Returns pointer to group found, NULL if not found.
  */
 
 struct t_gui_nick_group *
-gui_nicklist_search_group_internal (struct t_gui_buffer *buffer,
-                                    struct t_gui_nick_group *from_group,
-                                    const char *name,
-                                    int skip_digits)
+gui_nicklist_search_group_id (struct t_gui_buffer *buffer,
+                              struct t_gui_nick_group *from_group,
+                              long long id)
 {
-    struct t_gui_nick_group *ptr_group;
-    const char *ptr_name;
-
-    if (!buffer || !name)
-        return NULL;
+    struct t_gui_nick_group *ptr_group, *ptr_group_found;
 
     if (!from_group)
         from_group = buffer->nicklist_root;
@@ -205,24 +197,64 @@ gui_nicklist_search_group_internal (struct t_gui_buffer *buffer,
     if (!from_group)
         return NULL;
 
+    if (from_group->id == id)
+        return from_group;
+
     if (from_group->children)
     {
-        ptr_group = gui_nicklist_search_group_internal (buffer,
-                                                        from_group->children,
-                                                        name,
-                                                        skip_digits);
-        if (ptr_group)
-            return ptr_group;
+        for (ptr_group = from_group->children; ptr_group;
+             ptr_group = ptr_group->next_group)
+        {
+            ptr_group_found = gui_nicklist_search_group_id (buffer, ptr_group, id);
+            if (ptr_group_found)
+                return ptr_group_found;
+        }
     }
 
-    ptr_group = from_group;
-    while (ptr_group)
+    /* group not found */
+    return NULL;
+}
+
+/*
+ * Searches for a group in nicklist by name (this function must not be called
+ * directly).
+ *
+ * Returns pointer to group found, NULL if not found.
+ */
+
+struct t_gui_nick_group *
+gui_nicklist_search_group_name (struct t_gui_buffer *buffer,
+                                struct t_gui_nick_group *from_group,
+                                const char *name,
+                                int skip_digits)
+{
+    struct t_gui_nick_group *ptr_group, *ptr_group_found;
+    const char *ptr_name;
+
+    if (!from_group)
+        from_group = buffer->nicklist_root;
+
+    if (!from_group)
+        return NULL;
+
+    ptr_name = (skip_digits) ?
+        gui_nicklist_get_group_start (from_group->name) : from_group->name;
+    if (strcmp (ptr_name, name) == 0)
+        return from_group;
+
+    if (from_group->children)
     {
-        ptr_name = (skip_digits) ?
-            gui_nicklist_get_group_start (ptr_group->name) : ptr_group->name;
-        if (strcmp (ptr_name, name) == 0)
-            return ptr_group;
-        ptr_group = ptr_group->next_group;
+        for (ptr_group = from_group->children; ptr_group;
+             ptr_group = ptr_group->next_group)
+        {
+            ptr_group_found = gui_nicklist_search_group_name (
+                buffer,
+                ptr_group,
+                name,
+                skip_digits);
+            if (ptr_group_found)
+                return ptr_group_found;
+        }
     }
 
     /* group not found */
@@ -241,26 +273,68 @@ gui_nicklist_search_group (struct t_gui_buffer *buffer,
                            const char *name)
 {
     const char *ptr_name;
+    char *error;
+    long long id;
 
-    if (!buffer || !name)
+    if ((!buffer && !from_group)
+        || !name
+        || (!from_group && !buffer->nicklist_root))
+    {
         return NULL;
+    }
+
+    if (strncmp (name, "==id:", 5) == 0)
+    {
+        id = strtoll (name + 5, &error, 10);
+        if (error && !error[0])
+            return gui_nicklist_search_group_id (buffer, from_group, id);
+    }
 
     ptr_name = gui_nicklist_get_group_start (name);
-
-    return gui_nicklist_search_group_internal (buffer, from_group, name,
-                                               (ptr_name == name) ? 1 : 0);
+    return gui_nicklist_search_group_name (buffer, from_group, name,
+                                           (ptr_name == name) ? 1 : 0);
 }
 
 /*
- * Adds a group to nicklist.
+ * Returns a new unique id for a group/nick.
+ *
+ * The id is the current time with microseconds precision.
+ * The same time (including microseconds) can be used only one time, so that
+ * all group/nick ids in a given buffer are guaranteed to be unique.
+ */
+
+long long
+gui_nicklist_generate_id (struct t_gui_buffer *buffer)
+{
+    struct timeval tv;
+    long long id;
+
+    gettimeofday (&tv, NULL);
+
+    id = ((long long)tv.tv_sec * 1000000LL) + (long long)(tv.tv_usec);
+
+    /*
+     * ensure we never use the same id for two groups/nicks in the buffer
+     * and that the returned id is strictly greater than the last assigned one
+     * in the buffer
+     */
+    if (id <= buffer->nicklist_last_id_assigned)
+        id = buffer->nicklist_last_id_assigned + 1;
+
+    return id;
+}
+
+/*
+ * Adds a group to nicklist with identifier (internal use).
  *
  * Returns pointer to new group, NULL if error.
  */
 
 struct t_gui_nick_group *
-gui_nicklist_add_group (struct t_gui_buffer *buffer,
-                        struct t_gui_nick_group *parent_group, const char *name,
-                        const char *color, int visible)
+gui_nicklist_add_group_with_id (struct t_gui_buffer *buffer, long long id,
+                                struct t_gui_nick_group *parent_group,
+                                const char *name, const char *color,
+                                int visible)
 {
     struct t_gui_nick_group *new_group;
 
@@ -271,6 +345,9 @@ gui_nicklist_add_group (struct t_gui_buffer *buffer,
     if (!new_group)
         return NULL;
 
+    new_group->id = id;
+    if (new_group->id > buffer->nicklist_last_id_assigned)
+        buffer->nicklist_last_id_assigned = new_group->id;
     new_group->name = (char *)string_shared_get (name);
     new_group->color = (color) ? (char *)string_shared_get (color) : NULL;
     new_group->visible = visible;
@@ -308,6 +385,29 @@ gui_nicklist_add_group (struct t_gui_buffer *buffer,
     return new_group;
 }
 
+/*
+ * Adds a group to nicklist.
+ *
+ * Returns pointer to new group, NULL if error.
+ */
+
+struct t_gui_nick_group *
+gui_nicklist_add_group (struct t_gui_buffer *buffer,
+                        struct t_gui_nick_group *parent_group, const char *name,
+                        const char *color, int visible)
+{
+    if (!buffer)
+        return NULL;
+
+    return gui_nicklist_add_group_with_id (
+        buffer,
+        gui_nicklist_generate_id (buffer),
+        parent_group,
+        name,
+        color,
+        visible);
+}
+
 /*
  * Searches for position of a nick (to keep nicklist sorted).
  */
@@ -375,27 +475,54 @@ gui_nicklist_insert_nick_sorted (struct t_gui_nick_group *group,
 }
 
 /*
- * Searches for a nick in nicklist.
+ * Searches for a nick in nicklist by id (this function must not be called
+ * directly).
  *
  * Returns pointer to nick found, NULL if not found.
  */
 
 struct t_gui_nick *
-gui_nicklist_search_nick (struct t_gui_buffer *buffer,
-                          struct t_gui_nick_group *from_group,
-                          const char *name)
+gui_nicklist_search_nick_id (struct t_gui_buffer *buffer,
+                             struct t_gui_nick_group *from_group,
+                             long long id)
 {
     struct t_gui_nick *ptr_nick;
     struct t_gui_nick_group *ptr_group;
 
-    if (!buffer && !from_group)
-        return NULL;
+    for (ptr_nick = (from_group) ? from_group->nicks : buffer->nicklist_root->nicks;
+         ptr_nick; ptr_nick = ptr_nick->next_nick)
+    {
+        if (ptr_nick->id == id)
+            return ptr_nick;
+    }
 
-    if (!name)
-        return NULL;
+    /* search nick in child groups */
+    for (ptr_group = (from_group) ? from_group->children : buffer->nicklist_root->children;
+         ptr_group; ptr_group = ptr_group->next_group)
+    {
+        ptr_nick = gui_nicklist_search_nick_id (buffer, ptr_group, id);
+        if (ptr_nick)
+            return ptr_nick;
+    }
 
-    if (!from_group && !buffer->nicklist_root)
-        return NULL;
+    /* nick not found */
+    return NULL;
+}
+
+/*
+ * Searches for a nick in nicklist by name (this function must not be called
+ * directly).
+ *
+ * Returns pointer to nick found, NULL if not found.
+ */
+
+struct t_gui_nick *
+gui_nicklist_search_nick_name (struct t_gui_buffer *buffer,
+                               struct t_gui_nick_group *from_group,
+                               const char *name)
+{
+    struct t_gui_nick *ptr_nick;
+    struct t_gui_nick_group *ptr_group;
 
     for (ptr_nick = (from_group) ? from_group->nicks : buffer->nicklist_root->nicks;
          ptr_nick; ptr_nick = ptr_nick->next_nick)
@@ -420,7 +547,7 @@ gui_nicklist_search_nick (struct t_gui_buffer *buffer,
     for (ptr_group = (from_group) ? from_group->children : buffer->nicklist_root->children;
          ptr_group; ptr_group = ptr_group->next_group)
     {
-        ptr_nick = gui_nicklist_search_nick (buffer, ptr_group, name);
+        ptr_nick = gui_nicklist_search_nick_name (buffer, ptr_group, name);
         if (ptr_nick)
             return ptr_nick;
     }
@@ -430,17 +557,48 @@ gui_nicklist_search_nick (struct t_gui_buffer *buffer,
 }
 
 /*
- * Adds a nick to nicklist.
+ * Searches for a nick in nicklist.
+ *
+ * Returns pointer to nick found, NULL if not found.
+ */
+
+struct t_gui_nick *
+gui_nicklist_search_nick (struct t_gui_buffer *buffer,
+                          struct t_gui_nick_group *from_group,
+                          const char *name)
+{
+    long long id;
+    char *error;
+
+    if ((!buffer && !from_group)
+        || !name
+        || (!from_group && !buffer->nicklist_root))
+    {
+        return NULL;
+    }
+
+    if (strncmp (name, "==id:", 5) == 0)
+    {
+        id = strtoll (name + 5, &error, 10);
+        if (error && !error[0])
+            return gui_nicklist_search_nick_id (buffer, from_group, id);
+    }
+
+    return gui_nicklist_search_nick_name (buffer, from_group, name);
+}
+
+/*
+ * Adds a nick to nicklist with identifier (internal use).
  *
  * Returns pointer to new nick, NULL if error.
  */
 
 struct t_gui_nick *
-gui_nicklist_add_nick (struct t_gui_buffer *buffer,
-                       struct t_gui_nick_group *group,
-                       const char *name, const char *color,
-                       const char *prefix, const char *prefix_color,
-                       int visible)
+gui_nicklist_add_nick_with_id (struct t_gui_buffer *buffer, long long id,
+                               struct t_gui_nick_group *group,
+                               const char *name, const char *color,
+                               const char *prefix, const char *prefix_color,
+                               int visible)
 {
     struct t_gui_nick *new_nick;
 
@@ -451,6 +609,9 @@ gui_nicklist_add_nick (struct t_gui_buffer *buffer,
     if (!new_nick)
         return NULL;
 
+    new_nick->id = id;
+    if (new_nick->id > buffer->nicklist_last_id_assigned)
+        buffer->nicklist_last_id_assigned = new_nick->id;
     new_nick->group = (group) ? group : buffer->nicklist_root;
     new_nick->name = (char *)string_shared_get (name);
     new_nick->color = (color) ? (char *)string_shared_get (color) : NULL;
@@ -478,6 +639,33 @@ gui_nicklist_add_nick (struct t_gui_buffer *buffer,
     return new_nick;
 }
 
+/*
+ * Adds a nick to nicklist.
+ *
+ * Returns pointer to new nick, NULL if error.
+ */
+
+struct t_gui_nick *
+gui_nicklist_add_nick (struct t_gui_buffer *buffer,
+                       struct t_gui_nick_group *group,
+                       const char *name, const char *color,
+                       const char *prefix, const char *prefix_color,
+                       int visible)
+{
+    if (!buffer)
+        return NULL;
+
+    return gui_nicklist_add_nick_with_id (
+        buffer,
+        gui_nicklist_generate_id (buffer),
+        group,
+        name,
+        color,
+        prefix,
+        prefix_color,
+        visible);
+}
+
 /*
  * Removes a nick from a group.
  */
@@ -507,14 +695,10 @@ gui_nicklist_remove_nick (struct t_gui_buffer *buffer,
         (nick->group)->last_nick = nick->prev_nick;
 
     /* free data */
-    if (nick->name)
-        string_shared_free (nick->name);
-    if (nick->color)
-        string_shared_free (nick->color);
-    if (nick->prefix)
-        string_shared_free (nick->prefix);
-    if (nick->prefix_color)
-        string_shared_free (nick->prefix_color);
+    string_shared_free (nick->name);
+    string_shared_free (nick->color);
+    string_shared_free (nick->prefix);
+    string_shared_free (nick->prefix_color);
 
     buffer->nicklist_count--;
     buffer->nicklist_nicks_count--;
@@ -534,8 +718,7 @@ gui_nicklist_remove_nick (struct t_gui_buffer *buffer,
 
     gui_nicklist_send_signal ("nicklist_nick_removed", buffer, nick_removed);
 
-    if (nick_removed)
-        free (nick_removed);
+    free (nick_removed);
 }
 
 /*
@@ -589,10 +772,8 @@ gui_nicklist_remove_group (struct t_gui_buffer *buffer,
     }
 
     /* free data */
-    if (group->name)
-        string_shared_free (group->name);
-    if (group->color)
-        string_shared_free (group->color);
+    string_shared_free (group->name);
+    string_shared_free (group->color);
 
     if (buffer->nicklist_display_groups && group->visible)
     {
@@ -606,8 +787,7 @@ gui_nicklist_remove_group (struct t_gui_buffer *buffer,
 
     gui_nicklist_send_signal ("nicklist_group_removed", buffer, group_removed);
 
-    if (group_removed)
-        free (group_removed);
+    free (group_removed);
 }
 
 /*
@@ -725,66 +905,17 @@ gui_nicklist_get_group_start (const char *name)
 {
     const char *ptr_name;
 
+    if (!name)
+        return NULL;
+
     ptr_name = name;
     while (isdigit ((unsigned char)ptr_name[0]))
     {
-        if (ptr_name[0] == '|')
-            break;
         ptr_name++;
     }
-    if ((ptr_name[0] == '|') && (ptr_name != name))
+    if ((ptr_name > name) && (ptr_name[0] == '|'))
         return ptr_name + 1;
-    else
-        return name;
-}
-
-/*
- * Returns longer nickname in the nicklist.
- */
-
-int
-gui_nicklist_get_max_length (struct t_gui_buffer *buffer,
-                             struct t_gui_nick_group *group)
-{
-    int length, max_length;
-    struct t_gui_nick_group *ptr_group;
-    struct t_gui_nick *ptr_nick;
-
-    if (!buffer)
-        return 0;
-
-    max_length = 0;
-    for (ptr_group = (group) ? group : buffer->nicklist_root;
-         ptr_group; ptr_group = ptr_group->next_group)
-    {
-        if (buffer->nicklist_display_groups && ptr_group->visible)
-        {
-            length = utf8_strlen_screen (gui_nicklist_get_group_start (ptr_group->name)) +
-                                         ptr_group->level - 1;
-            if (length > max_length)
-                max_length = length;
-        }
-        for (ptr_nick = ptr_group->nicks; ptr_nick;
-             ptr_nick = ptr_nick->next_nick)
-        {
-            if (ptr_nick->visible)
-            {
-                if (buffer->nicklist_display_groups)
-                    length = utf8_strlen_screen (ptr_nick->name) + ptr_group->level + 1;
-                else
-                    length = utf8_strlen_screen (ptr_nick->name) + 1;
-                if (length > max_length)
-                    max_length = length;
-            }
-        }
-        if (ptr_group->children)
-        {
-            length = gui_nicklist_get_max_length (buffer, ptr_group->children);
-            if (length > max_length)
-                max_length = length;
-        }
-    }
-    return max_length;
+    return name;
 }
 
 /*
@@ -902,6 +1033,7 @@ gui_nicklist_group_set (struct t_gui_buffer *buffer,
                         struct t_gui_nick_group *group,
                         const char *property, const char *value)
 {
+    long long id;
     long number;
     char *error;
     int group_changed;
@@ -911,10 +1043,20 @@ gui_nicklist_group_set (struct t_gui_buffer *buffer,
 
     group_changed = 0;
 
-    if (strcmp (property, "color") == 0)
+    if (strcmp (property, "id") == 0)
     {
-        if (group->color)
-            string_shared_free (group->color);
+        id = strtoll (value, &error, 10);
+        if (error && !error[0]
+            && (id != group->id)
+            && !gui_nicklist_search_group_id (buffer, NULL, id))
+        {
+            group->id = id;
+            group_changed = 1;
+        }
+    }
+    else if (strcmp (property, "color") == 0)
+    {
+        string_shared_free (group->color);
         group->color = (value[0]) ? (char *)string_shared_get (value) : NULL;
         group_changed = 1;
     }
@@ -1013,6 +1155,7 @@ gui_nicklist_nick_set (struct t_gui_buffer *buffer,
                        struct t_gui_nick *nick,
                        const char *property, const char *value)
 {
+    long long id;
     long number;
     char *error;
     int nick_changed;
@@ -1022,24 +1165,32 @@ gui_nicklist_nick_set (struct t_gui_buffer *buffer,
 
     nick_changed = 0;
 
-    if (strcmp (property, "color") == 0)
+    if (strcmp (property, "id") == 0)
     {
-        if (nick->color)
-            string_shared_free (nick->color);
+        id = strtoll (value, &error, 10);
+        if (error && !error[0]
+            && (id != nick->id)
+            && !gui_nicklist_search_nick_id (buffer, NULL, id))
+        {
+            nick->id = id;
+            nick_changed = 1;
+        }
+    }
+    else if (strcmp (property, "color") == 0)
+    {
+        string_shared_free (nick->color);
         nick->color = (value[0]) ? (char *)string_shared_get (value) : NULL;
         nick_changed = 1;
     }
     else if (strcmp (property, "prefix") == 0)
     {
-        if (nick->prefix)
-            string_shared_free (nick->prefix);
+        string_shared_free (nick->prefix);
         nick->prefix = (value[0]) ? (char *)string_shared_get (value) : NULL;
         nick_changed = 1;
     }
     else if (strcmp (property, "prefix_color") == 0)
     {
-        if (nick->prefix_color)
-            string_shared_free (nick->prefix_color);
+        string_shared_free (nick->prefix_color);
         nick->prefix_color = (value[0]) ? (char *)string_shared_get (value) : NULL;
         nick_changed = 1;
     }
@@ -1078,6 +1229,7 @@ gui_nicklist_hdata_nick_group_cb (const void *pointer, void *data,
                        0, 0, NULL, NULL);
     if (hdata)
     {
+        HDATA_VAR(struct t_gui_nick_group, id, LONGLONG, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_nick_group, name, SHARED_STRING, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_nick_group, color, SHARED_STRING, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_nick_group, visible, INTEGER, 0, NULL, NULL);
@@ -1111,6 +1263,7 @@ gui_nicklist_hdata_nick_cb (const void *pointer, void *data,
                        0, 0, NULL, NULL);
     if (hdata)
     {
+        HDATA_VAR(struct t_gui_nick, id, LONGLONG, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_nick, group, POINTER, 0, NULL, "nick_group");
         HDATA_VAR(struct t_gui_nick, name, SHARED_STRING, 0, NULL, NULL);
         HDATA_VAR(struct t_gui_nick, color, SHARED_STRING, 0, NULL, NULL);
@@ -1136,6 +1289,7 @@ gui_nicklist_add_group_to_infolist (struct t_infolist *infolist,
                                     struct t_gui_nick_group *group)
 {
     struct t_infolist_item *ptr_item;
+    char str_value[64];
 
     if (!infolist || !group)
         return 0;
@@ -1144,6 +1298,9 @@ gui_nicklist_add_group_to_infolist (struct t_infolist *infolist,
     if (!ptr_item)
         return 0;
 
+    snprintf (str_value, sizeof (str_value), "%lld", group->id);
+    if (!infolist_new_var_string (ptr_item, "id", str_value))
+        return 0;
     if (!infolist_new_var_string (ptr_item, "type", "group"))
         return 0;
     if (group->parent)
@@ -1176,6 +1333,7 @@ gui_nicklist_add_nick_to_infolist (struct t_infolist *infolist,
                                    struct t_gui_nick *nick)
 {
     struct t_infolist_item *ptr_item;
+    char str_value[64];
 
     if (!infolist || !nick)
         return 0;
@@ -1184,6 +1342,9 @@ gui_nicklist_add_nick_to_infolist (struct t_infolist *infolist,
     if (!ptr_item)
         return 0;
 
+    snprintf (str_value, sizeof (str_value), "%lld", nick->id);
+    if (!infolist_new_var_string (ptr_item, "id", str_value))
+        return 0;
     if (!infolist_new_var_string (ptr_item, "type", "nick"))
         return 0;
     if (nick->group)
@@ -1270,9 +1431,13 @@ gui_nicklist_print_log (struct t_gui_nick_group *group, int indent)
     struct t_gui_nick *ptr_nick;
 
     snprintf (format, sizeof (format),
-              "%%-%ds=> group (addr:0x%%lx)",
+              "%%-%ds=> group (addr:%%p)",
               (indent * 2) + 4);
     log_printf (format, " ", group);
+    snprintf (format, sizeof (format),
+              "%%-%dsid. . . . . : %%lld",
+              (indent * 2) + 6);
+    log_printf (format, " ", group->id);
     snprintf (format, sizeof (format),
               "%%-%dsname. . . . : '%%s'",
               (indent * 2) + 6);
@@ -1286,31 +1451,31 @@ gui_nicklist_print_log (struct t_gui_nick_group *group, int indent)
               (indent * 2) + 6);
     log_printf (format, " ", group->visible);
     snprintf (format, sizeof (format),
-              "%%-%dsparent. . . : 0x%%lx",
+              "%%-%dsparent. . . : %%p",
               (indent * 2) + 6);
     log_printf (format, " ", group->parent);
     snprintf (format, sizeof (format),
-              "%%-%dschildren. . : 0x%%lx",
+              "%%-%dschildren. . : %%p",
               (indent * 2) + 6);
     log_printf (format, " ", group->children);
     snprintf (format, sizeof (format),
-              "%%-%dslast_child. : 0x%%lx",
+              "%%-%dslast_child. : %%p",
               (indent * 2) + 6);
     log_printf (format, " ", group->last_child);
     snprintf (format, sizeof (format),
-              "%%-%dsnicks . . . : 0x%%lx",
+              "%%-%dsnicks . . . : %%p",
               (indent * 2) + 6);
     log_printf (format, " ", group->nicks);
     snprintf (format, sizeof (format),
-              "%%-%dslast_nick . : 0x%%lx",
+              "%%-%dslast_nick . : %%p",
               (indent * 2) + 6);
     log_printf (format, " ", group->last_nick);
     snprintf (format, sizeof (format),
-              "%%-%dsprev_group. : 0x%%lx",
+              "%%-%dsprev_group. : %%p",
               (indent * 2) + 6);
     log_printf (format, " ", group->prev_group);
     snprintf (format, sizeof (format),
-              "%%-%dsnext_group. : 0x%%lx",
+              "%%-%dsnext_group. : %%p",
               (indent * 2) + 6);
     log_printf (format, " ", group->next_group);
 
@@ -1329,13 +1494,17 @@ gui_nicklist_print_log (struct t_gui_nick_group *group, int indent)
          ptr_nick = ptr_nick->next_nick)
     {
         snprintf (format, sizeof (format),
-                  "%%-%ds=> nick (addr:0x%%lx)",
+                  "%%-%ds=> nick (addr:%%p)",
                   (indent * 2) + 4);
         log_printf (format, " ", ptr_nick);
         snprintf (format, sizeof (format),
-                  "%%-%dsgroup . . . . . : 0x%%lx",
+                  "%%-%dsgroup . . . . . : %%p",
                   (indent * 2) + 6);
         log_printf (format, " ", ptr_nick->group);
+        snprintf (format, sizeof (format),
+                  "%%-%dsid. . . . . . . : %%lld",
+                  (indent * 2) + 6);
+        log_printf (format, " ", ptr_nick->id);
         snprintf (format, sizeof (format),
                   "%%-%dsname. . . . . . : '%%s'",
                   (indent * 2) + 6);
@@ -1357,11 +1526,11 @@ gui_nicklist_print_log (struct t_gui_nick_group *group, int indent)
                   (indent * 2) + 6);
         log_printf (format, " ", ptr_nick->visible);
         snprintf (format, sizeof (format),
-                  "%%-%dsprev_nick . . . : 0x%%lx",
+                  "%%-%dsprev_nick . . . : %%p",
                   (indent * 2) + 6);
         log_printf (format, " ", ptr_nick->prev_nick);
         snprintf (format, sizeof (format),
-                  "%%-%dsnext_nick . . . : 0x%%lx",
+                  "%%-%dsnext_nick . . . : %%p",
                   (indent * 2) + 6);
         log_printf (format, " ", ptr_nick->next_nick);
     }
@@ -1372,7 +1541,7 @@ gui_nicklist_print_log (struct t_gui_nick_group *group, int indent)
  */
 
 void
-gui_nicklist_end ()
+gui_nicklist_end (void)
 {
     if (gui_nicklist_hsignal)
     {
