@@ -1,7 +1,7 @@
 /*
  * buflist.c - Bar with list of buffers
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -56,7 +56,7 @@ struct t_hdata *buflist_hdata_bar_window = NULL;
  */
 
 void
-buflist_add_bar ()
+buflist_add_bar (void)
 {
     weechat_bar_new (
         BUFLIST_BAR_NAME,
