@@ -2,7 +2,7 @@
  * weechat-lua.c - lua plugin for WeeChat
  *
  * Copyright (C) 2006-2007 Emmanuel Bouthenot <kolter@openics.org>
- * Copyright (C) 2006-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2006-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -186,13 +186,12 @@ weechat_lua_tohashtable (lua_State *interpreter, int index, int size,
  */
 
 void
-weechat_lua_output_flush ()
+weechat_lua_output_flush (void)
 {
     const char *ptr_command;
     char *temp_buffer, *command;
-    int length;
 
-    if (!*lua_buffer_output[0])
+    if (!(*lua_buffer_output)[0])
         return;
 
     /* if there's no buffer, we catch the output, so there's no flush */
@@ -219,12 +218,11 @@ weechat_lua_output_flush ()
             }
             else
             {
-                length = 1 + strlen (temp_buffer) + 1;
-                command = malloc (length);
-                if (command)
+                if (weechat_asprintf (&command,
+                                      "%c%s",
+                                      temp_buffer[0],
+                                      temp_buffer) >= 0)
                 {
-                    snprintf (command, length, "%c%s",
-                              temp_buffer[0], temp_buffer);
                     weechat_command (lua_eval_buffer,
                                      (command[0]) ? command : " ");
                     free (command);
@@ -840,7 +838,7 @@ weechat_lua_reload_name (const char *name)
  */
 
 void
-weechat_lua_unload_all ()
+weechat_lua_unload_all (void)
 {
     while (lua_scripts)
     {
