@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,16 +14,20 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_SCRIPT_ACTION_H
-#define WEECHAT_SCRIPT_ACTION_H 1
+#ifndef WEECHAT_PLUGIN_SCRIPT_ACTION_H
+#define WEECHAT_PLUGIN_SCRIPT_ACTION_H
 
-extern char *script_actions;
+extern char **script_actions;
 
-extern int script_action_run ();
-extern void script_action_schedule (const char *action, int need_repository,
+extern int script_action_run_all (void);
+extern void script_action_schedule (struct t_gui_buffer *buffer,
+                                    const char *action,
+                                    int need_repository,
+                                    int error_repository,
                                     int quiet);
+extern void script_action_end (void);
 
-#endif /* WEECHAT_SCRIPT_ACTION_H */
+#endif /* WEECHAT_PLUGIN_SCRIPT_ACTION_H */
