@@ -1,7 +1,7 @@
 /*
  * script-command.c - script command
  *
- * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -154,6 +154,18 @@ script_command_script (const void *pointer, void *data,
         return WEECHAT_RC_OK;
     }
 
+    if (weechat_strcmp (argv[1], "enable") == 0)
+    {
+        if (!weechat_config_boolean (script_config_scripts_download_enabled))
+        {
+            weechat_config_option_set (script_config_scripts_download_enabled, "on", 1);
+            weechat_printf (NULL,
+                            _("%s: download of scripts enabled"),
+                            SCRIPT_PLUGIN_NAME);
+        }
+        return WEECHAT_RC_OK;
+    }
+
     if (weechat_strcmp (argv[1], "list") == 0)
     {
         script_action_schedule (buffer, argv_eol[1], 1, 0, 0);
@@ -303,23 +315,26 @@ script_command_script (const void *pointer, void *data,
  */
 
 void
-script_command_init ()
+script_command_init (void)
 {
     weechat_hook_command (
         "script",
         N_("WeeChat script manager"),
-        /* TRANSLATORS: only text between angle brackets (eg: "<name>") must be translated */
-        N_("list [-o|-ol|-i|-il]"
+        /* TRANSLATORS: only text between angle brackets (eg: "<name>") may be translated */
+        N_("enable"
+           " || list [-o|-ol|-i|-il]"
            " || search <text>"
            " || show <script>"
-           " || load|unload|reload <script> [<script>...]"
-           " || autoload|noautoload|toggleautoload <script> [<script>...]"
-           " || install|remove|installremove|hold [-q] <script> [<script>...]"
+           " || load|unload|reload <script>..."
+           " || autoload|noautoload|toggleautoload <script>..."
+           " || install|remove|installremove|hold [-q] <script>..."
            " || upgrade"
            " || update"
            " || -up|-down [<number>]"
            " || -go <line>|end"),
         WEECHAT_CMD_ARGS_DESC(
+            N_("raw[enable]: enable download of scripts "
+               "(turn on option script.scripts.download_enabled)"),
             N_("raw[list]: list loaded scripts (all languages)"),
             N_("raw[-o]: send list of loaded scripts to buffer "
                "(string in English)"),
@@ -344,7 +359,7 @@ script_command_init ()
             N_("raw[installremove]: install or remove script(s), depending on current "
                "state"),
             N_("raw[hold]: hold/unhold script(s) (a script held will not be "
-               "upgraded any more and cannot be removed)"),
+               "upgraded anymore and cannot be removed)"),
             N_("raw[-q]: quiet mode: do not display messages"),
             N_("raw[upgrade]: upgrade all installed scripts which are obsolete "
                "(new version available)"),
@@ -365,7 +380,7 @@ script_command_init ()
             N_("  `N`: obsolete (new version available)"),
             "",
             N_("In output of /script list, this additional status can be displayed:"),
-            N_("  `?`: unknown script (can not be downloaded/updated)"),
+            N_("  `?`: unknown script (cannot be downloaded/updated)"),
             "",
             N_("In input of script buffer, word(s) are used to filter scripts "
                "on description, tags, ...). The input \"*\" removes the filter."),
@@ -380,7 +395,8 @@ script_command_init ()
             AI("  /script hold urlserver.py"),
             AI("  /script reload urlserver"),
             AI("  /script upgrade")),
-        "list -i|-il|-o|-ol"
+        "enable"
+        " || list -i|-il|-o|-ol"
         " || search %(script_tags)|%(script_languages)|%(script_extensions)"
         " || show %(script_scripts)"
         " || load %(script_files)|%*"
