@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2015 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,12 +14,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef WEECHAT_XFER_INFO_H
-#define WEECHAT_XFER_INFO_H 1
+#ifndef WEECHAT_PLUGIN_XFER_INFO_H
+#define WEECHAT_PLUGIN_XFER_INFO_H
 
-extern void xfer_info_init ();
+extern void xfer_info_init (void);
 
-#endif /* WEECHAT_XFER_INFO_H */
+#endif /* WEECHAT_PLUGIN_XFER_INFO_H */
